@@ -1,4 +1,4 @@
-#!/usr/bin/python2.4
+#!/usr/bin/python
 #
 # Copyright 2007 Google Inc.
 #
@@ -28,14 +28,4 @@ nss_cache package.
 __author__ = ('jaq@google.com (Jamie Wilkinson)',
               'vasilios@google.com (Vasilios Hoffman)')
 
-__version__ = '0.8.8'
-
-import app
-import caches
-import command
-import config
-import error
-import lock
-import maps
-import nss
-import sources
+__version__ = '0.21.19'
